//-- There is NO need of any header
//-- Simply use the reference in the Project::Properties::Common Properties::Reference
//-- to add the SYN_API.DLL as reference
using	namespace	MOL;
using	namespace	MOL::SYN;
using	namespace	System::Threading;

//-- If you use the traditional unmanaged codes
//-- You can also include the header
#include <stdio.h>	// Header for unmanaged codes
#include <math.h>

#define	SINGLE_MODULE

//==============================================================================
//==============================================================================
unsigned	degree_to_phase_code( double phase )
{
	return (unsigned) ( 0x800 * phase / 360. ) & 0x7ff;
}

int	main( )
{
	SYN_Group_API	syn_group;
	SYN_API			syn;

	//---- Check if there is at least one syn module connected
	if( syn_group.number == 0 )
	{
		printf( "No SYN Module Exists!!\n" );
		return 1;
	}

	//---- Get the module series number
	//-- For single module, the first and only series number is index 0
#ifdef	SINGLE_MODULE
	int	SeriesNumber = syn_group.get_sn(0);
	printf( "Found Device with SN: %d\n", SeriesNumber );
#else
//	The following codes is for multiple modules
//	You must identify the series number of the desired module
	int	i, SeriesNumber;

	printf( "Input Series Number: ");
	scanf( "%d", &SeriesNumber );

	for( i=0; i<syn_group.number; i++ )
	{
		// SeriesNumber is the series number of the module you would like to control
		if( syn_group.get_sn( i ) == SeriesNumber ) break;
	}
	
	if( i==syn_group.number )
	{
		printf( "SYN101 SN %d Not Found!!\n", SeriesNumber );
		return 1;
	}
	printf( "Found Device with SN: %d\n", SeriesNumber );
#endif

	//---- Initialize the syn
	//---- If you use multiple modules of the same type
	//---- you must identify the series number for the specified module
	syn.ini( SeriesNumber );

	
	//---- Parameterize
	//---- Real frequency is (FREQUENCY_CODE / 2^30 ) * Clock
	//---- 1/16 clock in this example
	unsigned	frequency_code = 0x4000000;
	syn.frequency_code_cha = frequency_code;
	syn.frequency_code_chb = frequency_code;

	syn.sync = true ;
	syn.sync = false ;
	
	//---- Reset SYN101
	syn.reset	= true;		// Enable DDSes' Reset
	syn.reset	= false;	// Release DDSes' Reset

	syn.phase_code_cha = 0;
	while( 1 )
	{
		syn.phase_code_chb = degree_to_phase_code( 90 );
		printf( " CHA:   0 degree, CHB:  90 degree\n" );
		Thread::Sleep( 2000 );	// 2 second

		syn.phase_code_chb = degree_to_phase_code( 180 );
		printf( " CHA:   0 degree, CHB:  180 degree\n" );
		Thread::Sleep( 2000 );	// 2 second

		syn.phase_code_chb = degree_to_phase_code( 270 );
		printf( " CHA:   0 degree, CHB:  270 degree\n" );
		Thread::Sleep( 2000 );	// 2 second

		syn.phase_code_chb = degree_to_phase_code( 0 );
		printf( " CHA:   0 degree, CHB:  0 degree\n" );
		Thread::Sleep( 2000 );	// 2 second
	}
}